==> types_aiobotocore_importexport-2.5.2.post1-py3-none-any.whl: types_aiobotocore_importexport/type_defs.py <==
"""
Type annotations for importexport service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_importexport/type_defs/)

Usage::

    ```python
    from types_aiobotocore_importexport.type_defs import ArtifactTypeDef

    data: ArtifactTypeDef = ...
    ```
"""
import sys
from datetime import datetime
from typing import Dict, List, Sequence

from .literals import JobTypeType

if sys.version_info >= (3, 9):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "ArtifactTypeDef",
    "CancelJobInputRequestTypeDef",
    "ResponseMetadataTypeDef",
    "CreateJobInputRequestTypeDef",
    "GetShippingLabelInputRequestTypeDef",
    "GetStatusInputRequestTypeDef",
    "JobTypeDef",
    "PaginatorConfigTypeDef",
    "ListJobsInputRequestTypeDef",
    "UpdateJobInputRequestTypeDef",
    "CancelJobOutputTypeDef",
    "CreateJobOutputTypeDef",
    "GetShippingLabelOutputTypeDef",
    "GetStatusOutputTypeDef",
    "UpdateJobOutputTypeDef",
    "ListJobsOutputTypeDef",
    "ListJobsInputListJobsPaginateTypeDef",
)

ArtifactTypeDef = TypedDict(
    "ArtifactTypeDef",
    {
        "Description": str,
        "URL": str,
    },
    total=False,
)

_RequiredCancelJobInputRequestTypeDef = TypedDict(
    "_RequiredCancelJobInputRequestTypeDef",
    {
        "JobId": str,
    },
)
_OptionalCancelJobInputRequestTypeDef = TypedDict(
    "_OptionalCancelJobInputRequestTypeDef",
    {
        "APIVersion": str,
    },
    total=False,
)


class CancelJobInputRequestTypeDef(
    _RequiredCancelJobInputRequestTypeDef, _OptionalCancelJobInputRequestTypeDef
):
    pass


ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

_RequiredCreateJobInputRequestTypeDef = TypedDict(
    "_RequiredCreateJobInputRequestTypeDef",
    {
        "JobType": JobTypeType,
        "Manifest": str,
        "ValidateOnly": bool,
    },
)
_OptionalCreateJobInputRequestTypeDef = TypedDict(
    "_OptionalCreateJobInputRequestTypeDef",
    {
        "ManifestAddendum": str,
        "APIVersion": str,
    },
    total=False,
)


class CreateJobInputRequestTypeDef(
    _RequiredCreateJobInputRequestTypeDef, _OptionalCreateJobInputRequestTypeDef
):
    pass


_RequiredGetShippingLabelInputRequestTypeDef = TypedDict(
    "_RequiredGetShippingLabelInputRequestTypeDef",
    {
        "jobIds": Sequence[str],
    },
)
_OptionalGetShippingLabelInputRequestTypeDef = TypedDict(
    "_OptionalGetShippingLabelInputRequestTypeDef",
    {
        "name": str,
        "company": str,
        "phoneNumber": str,
        "country": str,
        "stateOrProvince": str,
        "city": str,
        "postalCode": str,
        "street1": str,
        "street2": str,
        "street3": str,
        "APIVersion": str,
    },
    total=False,
)


class GetShippingLabelInputRequestTypeDef(
    _RequiredGetShippingLabelInputRequestTypeDef, _OptionalGetShippingLabelInputRequestTypeDef
):
    pass


_RequiredGetStatusInputRequestTypeDef = TypedDict(
    "_RequiredGetStatusInputRequestTypeDef",
    {
        "JobId": str,
    },
)
_OptionalGetStatusInputRequestTypeDef = TypedDict(
    "_OptionalGetStatusInputRequestTypeDef",
    {
        "APIVersion": str,
    },
    total=False,
)


class GetStatusInputRequestTypeDef(
    _RequiredGetStatusInputRequestTypeDef, _OptionalGetStatusInputRequestTypeDef
):
    pass


JobTypeDef = TypedDict(
    "JobTypeDef",
    {
        "JobId": str,
        "CreationDate": datetime,
        "IsCanceled": bool,
        "JobType": JobTypeType,
    },
    total=False,
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": int,
        "PageSize": int,
        "StartingToken": str,
    },
    total=False,
)

ListJobsInputRequestTypeDef = TypedDict(
    "ListJobsInputRequestTypeDef",
    {
        "MaxJobs": int,
        "Marker": str,
        "APIVersion": str,
    },
    total=False,
)

_RequiredUpdateJobInputRequestTypeDef = TypedDict(
    "_RequiredUpdateJobInputRequestTypeDef",
    {
        "JobId": str,
        "Manifest": str,
        "JobType": JobTypeType,
        "ValidateOnly": bool,
    },
)
_OptionalUpdateJobInputRequestTypeDef = TypedDict(
    "_OptionalUpdateJobInputRequestTypeDef",
    {
        "APIVersion": str,
    },
    total=False,
)


class UpdateJobInputRequestTypeDef(
    _RequiredUpdateJobInputRequestTypeDef, _OptionalUpdateJobInputRequestTypeDef
):
    pass


CancelJobOutputTypeDef = TypedDict(
    "CancelJobOutputTypeDef",
    {
        "Success": bool,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateJobOutputTypeDef = TypedDict(
    "CreateJobOutputTypeDef",
    {
        "JobId": str,
        "JobType": JobTypeType,
        "Signature": str,
        "SignatureFileContents": str,
        "WarningMessage": str,
        "ArtifactList": List[ArtifactTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetShippingLabelOutputTypeDef = TypedDict(
    "GetShippingLabelOutputTypeDef",
    {
        "ShippingLabelURL": str,
        "Warning": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetStatusOutputTypeDef = TypedDict(
    "GetStatusOutputTypeDef",
    {
        "JobId": str,
        "JobType": JobTypeType,
        "LocationCode": str,
        "LocationMessage": str,
        "ProgressCode": str,
        "ProgressMessage": str,
        "Carrier": str,
        "TrackingNumber": str,
        "LogBucket": str,
        "LogKey": str,
        "ErrorCount": int,
        "Signature": str,
        "SignatureFileContents": str,
        "CurrentManifest": str,
        "CreationDate": datetime,
        "ArtifactList": List[ArtifactTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateJobOutputTypeDef = TypedDict(
    "UpdateJobOutputTypeDef",
    {
        "Success": bool,
        "WarningMessage": str,
        "ArtifactList": List[ArtifactTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListJobsOutputTypeDef = TypedDict(
    "ListJobsOutputTypeDef",
    {
        "Jobs": List[JobTypeDef],
        "IsTruncated": bool,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListJobsInputListJobsPaginateTypeDef = TypedDict(
    "ListJobsInputListJobsPaginateTypeDef",
    {
        "APIVersion": str,
        "PaginationConfig": PaginatorConfigTypeDef,
    },
    total=False,
)

==> types_aiobotocore_importexport-2.7.0-py3-none-any.whl: types_aiobotocore_importexport/type_defs.py <==
"""
Type annotations for importexport service type definitions.

[Open documentation](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_importexport/type_defs/)

Usage::

    ```python
    from types_aiobotocore_importexport.type_defs import ArtifactTypeDef

    data: ArtifactTypeDef = ...
    ```
"""

import sys
from datetime import datetime
from typing import Dict, List, Sequence

from .literals import JobTypeType

if sys.version_info >= (3, 12):
    from typing import NotRequired
else:
    from typing_extensions import NotRequired
if sys.version_info >= (3, 12):
    from typing import TypedDict
else:
    from typing_extensions import TypedDict


__all__ = (
    "ArtifactTypeDef",
    "CancelJobInputRequestTypeDef",
    "ResponseMetadataTypeDef",
    "CreateJobInputRequestTypeDef",
    "GetShippingLabelInputRequestTypeDef",
    "GetStatusInputRequestTypeDef",
    "JobTypeDef",
    "PaginatorConfigTypeDef",
    "ListJobsInputRequestTypeDef",
    "UpdateJobInputRequestTypeDef",
    "CancelJobOutputTypeDef",
    "CreateJobOutputTypeDef",
    "GetShippingLabelOutputTypeDef",
    "GetStatusOutputTypeDef",
    "UpdateJobOutputTypeDef",
    "ListJobsOutputTypeDef",
    "ListJobsInputListJobsPaginateTypeDef",
)

ArtifactTypeDef = TypedDict(
    "ArtifactTypeDef",
    {
        "Description": NotRequired[str],
        "URL": NotRequired[str],
    },
)

CancelJobInputRequestTypeDef = TypedDict(
    "CancelJobInputRequestTypeDef",
    {
        "JobId": str,
        "APIVersion": NotRequired[str],
    },
)

ResponseMetadataTypeDef = TypedDict(
    "ResponseMetadataTypeDef",
    {
        "RequestId": str,
        "HostId": str,
        "HTTPStatusCode": int,
        "HTTPHeaders": Dict[str, str],
        "RetryAttempts": int,
    },
)

CreateJobInputRequestTypeDef = TypedDict(
    "CreateJobInputRequestTypeDef",
    {
        "JobType": JobTypeType,
        "Manifest": str,
        "ValidateOnly": bool,
        "ManifestAddendum": NotRequired[str],
        "APIVersion": NotRequired[str],
    },
)

GetShippingLabelInputRequestTypeDef = TypedDict(
    "GetShippingLabelInputRequestTypeDef",
    {
        "jobIds": Sequence[str],
        "name": NotRequired[str],
        "company": NotRequired[str],
        "phoneNumber": NotRequired[str],
        "country": NotRequired[str],
        "stateOrProvince": NotRequired[str],
        "city": NotRequired[str],
        "postalCode": NotRequired[str],
        "street1": NotRequired[str],
        "street2": NotRequired[str],
        "street3": NotRequired[str],
        "APIVersion": NotRequired[str],
    },
)

GetStatusInputRequestTypeDef = TypedDict(
    "GetStatusInputRequestTypeDef",
    {
        "JobId": str,
        "APIVersion": NotRequired[str],
    },
)

JobTypeDef = TypedDict(
    "JobTypeDef",
    {
        "JobId": NotRequired[str],
        "CreationDate": NotRequired[datetime],
        "IsCanceled": NotRequired[bool],
        "JobType": NotRequired[JobTypeType],
    },
)

PaginatorConfigTypeDef = TypedDict(
    "PaginatorConfigTypeDef",
    {
        "MaxItems": NotRequired[int],
        "PageSize": NotRequired[int],
        "StartingToken": NotRequired[str],
    },
)

ListJobsInputRequestTypeDef = TypedDict(
    "ListJobsInputRequestTypeDef",
    {
        "MaxJobs": NotRequired[int],
        "Marker": NotRequired[str],
        "APIVersion": NotRequired[str],
    },
)

UpdateJobInputRequestTypeDef = TypedDict(
    "UpdateJobInputRequestTypeDef",
    {
        "JobId": str,
        "Manifest": str,
        "JobType": JobTypeType,
        "ValidateOnly": bool,
        "APIVersion": NotRequired[str],
    },
)

CancelJobOutputTypeDef = TypedDict(
    "CancelJobOutputTypeDef",
    {
        "Success": bool,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

CreateJobOutputTypeDef = TypedDict(
    "CreateJobOutputTypeDef",
    {
        "JobId": str,
        "JobType": JobTypeType,
        "Signature": str,
        "SignatureFileContents": str,
        "WarningMessage": str,
        "ArtifactList": List[ArtifactTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetShippingLabelOutputTypeDef = TypedDict(
    "GetShippingLabelOutputTypeDef",
    {
        "ShippingLabelURL": str,
        "Warning": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

GetStatusOutputTypeDef = TypedDict(
    "GetStatusOutputTypeDef",
    {
        "JobId": str,
        "JobType": JobTypeType,
        "LocationCode": str,
        "LocationMessage": str,
        "ProgressCode": str,
        "ProgressMessage": str,
        "Carrier": str,
        "TrackingNumber": str,
        "LogBucket": str,
        "LogKey": str,
        "ErrorCount": int,
        "Signature": str,
        "SignatureFileContents": str,
        "CurrentManifest": str,
        "CreationDate": datetime,
        "ArtifactList": List[ArtifactTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

UpdateJobOutputTypeDef = TypedDict(
    "UpdateJobOutputTypeDef",
    {
        "Success": bool,
        "WarningMessage": str,
        "ArtifactList": List[ArtifactTypeDef],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListJobsOutputTypeDef = TypedDict(
    "ListJobsOutputTypeDef",
    {
        "Jobs": List[JobTypeDef],
        "IsTruncated": bool,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

ListJobsInputListJobsPaginateTypeDef = TypedDict(
    "ListJobsInputListJobsPaginateTypeDef",
    {
        "APIVersion": NotRequired[str],
        "PaginationConfig": NotRequired[PaginatorConfigTypeDef],
    },
)
